Python: module src.topology

src.topology (12 November 2008) | index /Users/d3y382/workspaces/apbs-pdb2pqr/pdb2pqr/src/topology.py

`Parser for TOPOLOGY.xml
----------------------------
PDB2PQR -- An automated pipeline for the setup, execution, and analysis of
Poisson-Boltzmann electrostatics calculations
Copyright (c) 2002-2011, Jens Erik Nielsen, University College Dublin;
Nathan A. Baker, Battelle Memorial Institute, Developed at the Pacific
Northwest National Laboratory, operated by Battelle Memorial Institute,
Pacific Northwest Division for the U.S. Department Energy.;
Paul Czodrowski & Gerhard Klebe, University of Marburg.
All rights reserved.
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
* Neither the names of University College Dublin, Battelle Memorial Institute,
Pacific Northwest National Laboratory, US Department of Energy, or University
of Marburg nor the names of its contributors may be used to endorse or promote
products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------`

Modules
`` |  |
xml.sax |  |  |

Classes
`` |  | Topology TopologyAtom TopologyConformer TopologyConformerAdd TopologyConformerRemove TopologyDihedral TopologyReference TopologyResidue TopologyTautomer TopologyTitrationState xml.sax.handler.ContentHandler TopologyHandler
class Topology
`` | `Contains the structured definitions of residue reference coordinates as well as alternate titration, conformer, and tautomer states.`
| Methods defined here: __init__(self, topologyFile) `Initialize with the topology file reference ready for reading`
class TopologyAtom
`` | `A class for atom topology information`
| Methods defined here: __init__(self, parent) `Needs to be intialized with an upper-level class that contains an atoms array (e.g., TopologyReference or TopologyConformerAddition)` __str__(self)
class TopologyConformer
`` | `A class for topology conformer information`
| Methods defined here: __init__(self, topologyTautomer) `Initialize with a TopologyTautomer object` __str__(self)
class TopologyConformerAdd
`` | `A class for adding atoms to a conformer`
| Methods defined here: __init__(self, topologyConformer) `Initialize with a TopologyConformer object`
class TopologyConformerRemove
`` | `A class for removing atoms to a conformer`
| Methods defined here: __init__(self, topologyConformer) `Initialize with a TopologyConformer object`
class TopologyDihedral
`` | `A class for dihedral topology information.`
| Methods defined here: __init__(self, parent) `Needs a parent that has a dihedral list.` __str__(self)
class TopologyHandler(xml.sax.handler.ContentHandler)
`` | `Handler for XML-based topology files. Assumes the following hierarchy of tags: topology -->residue |-->reference |-->titrationstate |-->tautomer |-->conformer`
| Methods defined here: __init__(self) characters(self, text) endElement(self, tagName) startElement(self, tagName, attributes) Methods inherited from xml.sax.handler.ContentHandler: endDocument(self) `Receive notification of the end of a document. The SAX parser will invoke this method only once, and it will be the last method invoked during the parse. The parser shall not invoke this method until it has either abandoned parsing (because of an unrecoverable error) or reached the end of input.` endElementNS(self, name, qname) `Signals the end of an element in namespace mode. The name parameter contains the name of the element type, just as with the startElementNS event.` endPrefixMapping(self, prefix) `End the scope of a prefix-URI mapping. See startPrefixMapping for details. This event will always occur after the corresponding endElement event, but the order of endPrefixMapping events is not otherwise guaranteed.` ignorableWhitespace(self, whitespace) `Receive notification of ignorable whitespace in element content. Validating Parsers must use this method to report each chunk of ignorable whitespace (see the W3C XML 1.0 recommendation, section 2.10): non-validating parsers may also use this method if they are capable of parsing and using content models. SAX parsers may return all contiguous whitespace in a single chunk, or they may split it into several chunks; however, all of the characters in any single event must come from the same external entity, so that the Locator provides useful information.` processingInstruction(self, target, data) `Receive notification of a processing instruction. The Parser will invoke this method once for each processing instruction found: note that processing instructions may occur before or after the main document element. A SAX parser should never report an XML declaration (XML 1.0, section 2.8) or a text declaration (XML 1.0, section 4.3.1) using this method.` setDocumentLocator(self, locator) `Called by the parser to give the application a locator for locating the origin of document events. SAX parsers are strongly encouraged (though not absolutely required) to supply a locator: if it does so, it must supply the locator to the application by invoking this method before invoking any of the other methods in the DocumentHandler interface. The locator allows the application to determine the end position of any document-related event, even if the parser is not reporting an error. Typically, the application will use this information for reporting its own errors (such as character content that does not match an application's business rules). The information returned by the locator is probably not sufficient for use with a search engine. Note that the locator will return correct information only during the invocation of the events in this interface. The application should not attempt to use it at any other time.` skippedEntity(self, name) `Receive notification of a skipped entity. The Parser will invoke this method once for each entity skipped. Non-validating processors may skip entities if they have not seen the declarations (because, for example, the entity was declared in an external DTD subset). All processors may skip external entities, depending on the values of the http://xml.org/sax/features/external-general-entities and the http://xml.org/sax/features/external-parameter-entities properties.` startDocument(self) `Receive notification of the beginning of a document. The SAX parser will invoke this method only once, before any other methods in this interface or in DTDHandler (except for setDocumentLocator).` startElementNS(self, name, qname, attrs) `Signals the start of an element in namespace mode. The name parameter contains the name of the element type as a (uri, localname) tuple, the qname parameter the raw XML 1.0 name used in the source document, and the attrs parameter holds an instance of the Attributes class containing the attributes of the element. The uri part of the name tuple is None for elements which have no namespace.` startPrefixMapping(self, prefix, uri) `Begin the scope of a prefix-URI Namespace mapping. The information from this event is not necessary for normal Namespace processing: the SAX XML reader will automatically replace prefixes for element and attribute names when the http://xml.org/sax/features/namespaces feature is true (the default). There are cases, however, when applications need to use prefixes in character data or in attribute values, where they cannot safely be expanded automatically; the start/endPrefixMapping event supplies the information to the application to expand prefixes in those contexts itself, if necessary. Note that start/endPrefixMapping events are not guaranteed to be properly nested relative to each-other: all startPrefixMapping events will occur before the corresponding startElement event, and all endPrefixMapping events will occur after the corresponding endElement event, but their order is not guaranteed.`
class TopologyReference
`` | `A class for the reference structure of a residue`
| Methods defined here: __init__(self, topologyResidue) `Initialize with a TopologyResidue object`
class TopologyResidue
`` | `A class for residue topology information`
| Methods defined here: __init__(self, topology) `Initialize with a Topology object` __str__(self)
class TopologyTautomer
`` | `A class for topology tautomer information`
| Methods defined here: __init__(self, topologyTitrationState) `Initialize with a TopologyTitrationState object` __str__(self)
class TopologyTitrationState
`` | `A class for the titration state of a residue`
| Methods defined here: __init__(self, topologyResidue) `Initialize with a TopologyResidue object` __str__(self)

Data
`` |  | TOPOLOGYPATH = 'TOPOLOGY.xml' __author__ = 'Nathan Baker, Yong Huang' __date__ = '12 November 2008' stderr = <open file '<stderr>', mode 'w'>

Author
`` |  | Nathan Baker, Yong Huang